..
   Do not edit this .rst file directly — it’s generated programmatically.
   See doc/reference.sh.

==================================================
Module: ``features``
==================================================

`Leer en español </es/latest/reference/features.html>`_

- **list features**

List a cPanel account’s features.

*Example*

.. code:: sh

    $ cpanel list features

See a sample of the JSON result data at:
https://api.docs.cpanel.net/openapi/cpanel/operation/list_features/


